@@ -287,19 +287,27 @@ class Configuration:
         ssh_directory_path = ""
 
         # retrieve the user name
+        user_prompt_number = 0
         while not user_exists:
             user_name = input(
                 "Name of the user to access ssh(if empty, defaults to `" + default_user + "`): ")
             if(user_name == ""):
                 user_name = default_user
             object.config["COG_SSH_DEFAULT_USER"] = user_name
-
-            ssh_directory_path = "/home/" + user_name + "/.ssh/"
+            
+            if(user_name == "root"):
+                ssh_directory_path = "/root/.ssh/"
+            else:                
+                ssh_directory_path = "/home/" + user_name + "/.ssh/"
             if os.path.exists(ssh_directory_path):
                 user_exists = True
             else:
                 print("User " + user_name +
                       " doesn't seem to exist or openssh server is not installed.")
+                user_prompt_number = user_prompt_number + 1
+                if(user_prompt_number > 2):
+                    print("Failed to find user's openssh configuration directory.")
+                    return False
 
         # copy the keys to authorized_keys file if automatic authentication was enabled
         if object.config["COG_ENABLE_SSH_KEY_AUTH"] == "True":
