@@ -10,6 +10,8 @@ from mock import patch
 from cogniceptshell.configuration import Configuration
 from cogniceptshell.agent_life_cycle import AgentLifeCycle
 
+from tests.unit.mock_docker_client import MockDockerClient
+
 
 class SuccessEcrCredentials(object):
     def __init__(self):
@@ -190,7 +192,7 @@ def test_get_last_event(tmpdir, capsys):
     # check if file was found and printed 
     assert len(matches) == 1
 
-def test_parsing_ok_ria_logs(capsys):
+def test_parsing_ok_kriya_logs(capsys):
     agent_lifecycle = AgentLifeCycle()
 
     log = """[ INFO] [1594729019.086950527]: WEBRTC:: STATUS:: ERROR
@@ -205,7 +207,7 @@ def test_parsing_ok_ria_logs(capsys):
     matches = re.findall(r"ONLINE", output, re.MULTILINE)
     assert len(matches) == 1
 
-def test_parsing_not_init_ria_logs(capsys):
+def test_parsing_not_init_kriya_logs(capsys):
     agent_lifecycle = AgentLifeCycle()
 
     log = """[ INFO] [1594729019.169204677]: WEBSOCKET:: STATUS:: INIT"""
@@ -215,7 +217,7 @@ def test_parsing_not_init_ria_logs(capsys):
     matches = re.findall(r"NOT INITIALIZED", output, re.MULTILINE)
     assert len(matches) == 1
 
-def test_parsing_agent_error_ria_logs(capsys):
+def test_parsing_agent_error_kriya_logs(capsys):
     agent_lifecycle = AgentLifeCycle()
 
     log = """[ INFO] [1594729019.086950527]: WEBRTC:: STATUS:: OK
@@ -230,7 +232,7 @@ def test_parsing_agent_error_ria_logs(capsys):
     matches = re.findall(r"ERROR", output, re.MULTILINE)
     assert len(matches) == 1
 
-def test_parsing_websocket_error_ria_logs(capsys):
+def test_parsing_websocket_error_kriya_logs(capsys):
     agent_lifecycle = AgentLifeCycle()
 
     log = """[ INFO] [1594729019.086950527]: WEBRTC:: STATUS:: OK
@@ -245,7 +247,7 @@ def test_parsing_websocket_error_ria_logs(capsys):
     matches = re.findall(r"ERROR", output, re.MULTILINE)
     assert len(matches) == 1
 
-def test_parsing_webrtc_error_ria_logs(capsys):
+def test_parsing_webrtc_error_kriya_logs(capsys):
     agent_lifecycle = AgentLifeCycle()
 
     log = """[ INFO] [1594729019.086950527]: WEBRTC:: STATUS:: OK
@@ -275,25 +277,30 @@ def test_run(tmpdir, capsys):
     args.agents = True
 
     # run container
-    result = agent_lifecycle.restart(args)
-    assert result == True
+    mock_docker_client = MockDockerClient()
+    with patch("docker.from_env", new=lambda: mock_docker_client):
+        result = agent_lifecycle.start(args)
+        assert result == True
 
-    # check status
-    capsys.readouterr().out
-    agent_lifecycle.get_status(args)
-    output = str(capsys.readouterr().out)
-    matches1 = re.findall(r"ONLINE", output, re.MULTILINE)
-    assert len(matches1) == 1
+        # check status
+        output = capsys.readouterr().out
+        print(output)
+        agent_lifecycle.get_status(args)
+        output = str(capsys.readouterr().out)
 
-    result = agent_lifecycle.remove_agents(args)
-    assert result == True
+        print(output)
+        matches1 = re.findall(r"ONLINE", output, re.MULTILINE)
+        assert len(matches1) == 1
 
-    # check if offline
-    capsys.readouterr().out
-    agent_lifecycle.get_status(args)
-    output = str(capsys.readouterr().out)
-    matches2 = re.findall(r"CONTAINER NOT FOUND", output, re.MULTILINE)
-    assert len(matches2) == 1
+        result = agent_lifecycle.remove_agents(args)
+        assert result == True
+
+        # check if offline
+        capsys.readouterr().out
+        agent_lifecycle.get_status(args)
+        output = str(capsys.readouterr().out)
+        matches2 = re.findall(r"CONTAINER NOT FOUND", output, re.MULTILINE)
+        assert len(matches2) == 1
 
 
 def test_agent_restart(tmpdir, capsys):
@@ -310,33 +317,35 @@ def test_agent_restart(tmpdir, capsys):
     args.config = local_cfg    
     args.agents = True
 
-    # run container
-    args.list = ["test"]
-    result = agent_lifecycle.restart(args)
-    assert result == True
-    
-    args.list = ["test"]
+    mock_docker_client = MockDockerClient()
+    with patch("docker.from_env", new=lambda: mock_docker_client):
+        # run container
+        args.list = ["test"]
+        result = agent_lifecycle.restart(args)
+        assert result == True
+        
+        args.list = ["test"]
 
-    # run container
-    args.list = ["unknown_container"]
-    result = agent_lifecycle.restart(args)
-    assert result == False
+        # run container
+        args.list = ["unknown_container"]
+        result = agent_lifecycle.restart(args)
+        assert result == False
 
-    # run container
-    args.list = ["test","unknown_container"]
-    result = agent_lifecycle.restart(args)
-    assert result == False
+        # run container
+        args.list = ["test","unknown_container"]
+        result = agent_lifecycle.restart(args)
+        assert result == False
 
-    args.list = ["test"]
-    result = agent_lifecycle.remove_agents(args)
-    assert result == True
+        args.list = ["test"]
+        result = agent_lifecycle.remove_agents(args)
+        assert result == True
 
-    result = agent_lifecycle.start(args)
-    assert result == True
+        result = agent_lifecycle.start(args)
+        assert result == True
 
-    del args.list
-    result = agent_lifecycle.remove_agents(args)
-    assert result == True
+        del args.list
+        result = agent_lifecycle.remove_agents(args)
+        assert result == True
 
 
 def test_correct_ecr_credentials(tmpdir, capsys, monkeypatch):
